# Kisumu

> [!WARNING]
>
> This project is still under development, the interface are unstable and might break in future versions.

A simple cli in front of [Jinja RDF](https://github.com/AKSW/jinja-rdf) to render a template + an RDF graph -> a static document.

> [!NOTE]
>
> ## TODO
> - namespace prefixes should be supported in the templates
> - namespace prefixes should be supported when specifying a resource in the cli

## Related Projects

- [Jinja RDF](https://github.com/AKSW/jinja-rdf)
- [MkRdf](https://github.com/AKSW/mkrdf)
- [Jekyll RDF](https://github.com/AKSW/jekyll-rdf) ([read about the relation](https://github.com/AKSW/mkrdf/blob/main/README.md#jekyll-rdf))
